# coding: utf-8
u"""Вспомогательные средства для работы с датами."""


def date_range_to_str(date_from, date_to, can_be_one_day_long=False):
    u"""Возвращает строковое представление диапазона дат.

    Формат строки: "с дд.мм.гггг [по дд.мм.гггг]", или "дд.мм.гггг", если даты
    совпадают.

    Если указана только одна из дат то будет только
    "с дд.мм.гггг" или "по дд.мм.гггг", но если can_be_one_day_long=True,
    результат будет "дд.мм.гггг", для той даты, что указана.

    (<2001.01.01>, <2001.01.01>)       -> "01.01.2001"
    (<2001.01.01>, <2002.02.02>)       -> "с 01.01.2001 по 02.02.2002"
    (<2001.01.01>, None        )       -> "с 01.01.2001"
    (None,         <2002.02.02>)       -> "по 02.02.2002"
    (<2001.01.01>, None,       , True) -> "01.01.2001"
    (None,         <2002.02.02>, True) -> "02.02.2002"
    """
    def fmt(date):
        return date.strftime('%d.%m.%Y') if date else ''

    def validate_year(date):
        return (date if 1900 < date.year < 2100 else None) if date else None

    result = ''
    date_from = validate_year(date_from)
    date_to = validate_year(date_to)
    if date_from and date_to:
        assert date_from <= date_to
        if date_from == date_to:
            result = fmt(date_from)
        else:
            result = u'с %s по %s' % (fmt(date_from), fmt(date_to))
    else:
        if can_be_one_day_long:
            result = fmt(date_from or date_to or None)
        elif date_from:
            result = u'с %s' % fmt(date_from)
        elif date_to:
            result = u'по %s' % fmt(date_to)

    return result
